@@ -10,7 +10,7 @@ mod account_validators;
 
 declare_id!("QREGBnEj9Sa5uR91AV8u3FxThgP5ZCvdZUW2bHAkfNc");
 
-#[cfg(not(feature = "cpi"))]
+#[cfg(not(feature = "no-entrypoint"))]
 solana_security_txt::security_txt! {
     name: "Quarry Registry",
     project_url: "https://quarry.so",
@@ -103,3 +103,29 @@ pub struct Registry {
     /// Tokens
     pub tokens: Vec<Pubkey>,
 }
+
+impl Registry {
+    /// Number of bytes a [Registry] takes up when serialized.
+    pub fn byte_length(max_quarries: u16) -> usize {
+        (1 + 32 + 4 + 32 * max_quarries) as usize
+    }
+}
+
+#[cfg(test)]
+mod tests {
+    use anchor_lang::system_program;
+
+    use super::*;
+
+    #[test]
+    fn test_registry_len() {
+        let registry = Registry {
+            tokens: vec![system_program::ID, system_program::ID],
+            ..Default::default()
+        };
+        assert_eq!(
+            registry.try_to_vec().unwrap().len(),
+            Registry::byte_length(2)
+        );
+    }
+}
